@@ -16,12 +16,12 @@ from application.process import process, ProcessError
 # Some signal handlers
 def signal_handler(*args):
     """A sample signal handler"""
-    log.msg("first handler received signal %s" % args[0])
+    log.info("first handler received signal %s" % args[0])
 
 
 def signal_handler2(*args):
     """Another sample signal handler"""
-    log.msg("second handler received signal %s" % args[0])
+    log.info("second handler received signal %s" % args[0])
 
 
 # The application name.
@@ -34,8 +34,8 @@ name = 'process-example'
 process.runtime_directory = '/tmp'
 
 # These log lines will go to stdout.
-log.msg("Starting %s. Check syslog to see what's going on next." % name)
-log.msg("Use `watch -n .1 ls /tmp' to see how the pid file is created and deleted.")
+log.info("Starting %s. Check syslog to see what's going on next." % name)
+log.info("Use `watch -n .1 ls /tmp' to see how the pid file is created and deleted.")
 
 # Set the process to run in the background and create a pid file.
 # If daemonize is called without arguments or pidfile is None no pid file
@@ -43,15 +43,15 @@ log.msg("Use `watch -n .1 ls /tmp' to see how the pid file is created and delete
 pidfile = process.runtime_file('%s.pid' % name)
 try:
     process.daemonize(pidfile)
-except ProcessError, e:
-    log.fatal(str(e))
+except ProcessError as e:
+    log.fatal(e)
     sys.exit(1)
 
 # process was successfully put in the background. Redirect logging to syslog
 log.start_syslog(name)
 
 # This log line will go to syslog
-log.msg('application started (running in the background)')
+log.info('application started (running in the background)')
 
 # Add a signal handler for SIGUSR1
 process.signals.add_handler(signal.SIGUSR1, signal_handler)
@@ -61,18 +61,17 @@ process.signals.add_handler(signal.SIGUSR1, signal_handler)
 # from the main thread.
 process.signals.add_handler(signal.SIGUSR1, signal_handler2)
 
-log.msg("sending SIGUSR1 to self")
+log.info("sending SIGUSR1 to self")
 os.kill(os.getpid(), signal.SIGUSR1)
-log.msg("sleeping for 3 seconds")
+log.info("sleeping for 3 seconds")
 time.sleep(3)
 
 # Simulate some error
 try:
+    # noinspection PyUnresolvedReferences
     bar = foo
-except NameError, e:
-    log.error("cannot access foo: %s" % e)
-    # Also log the backtrace
-    log.exception()
-
-log.msg("program done, exiting")
+except NameError as e:
+    # Log an error message and the backtrace
+    log.exception("cannot access foo: %s" % e)
 
+log.info("program done, exiting")
